@@ -6,7 +6,7 @@ use crate::*;
 
 /// Various causes of failure for ffmpeg/ffprobe functions.
 #[derive(Error, Debug, Clone, Serialize, Deserialize)]
-pub enum FfmpegErrorKind {
+pub enum FfmpegError {
     /// Ffmpeg/Ffprobe command was not found. Make sure Ffmpeg is installed and can be found on the command line.
     #[error("ffmpeg/ffprobe file not found. Make sure ffmpeg/ffprobe are installed and visible on the command line")]
     FfmpegNotFound,
@@ -33,4 +33,8 @@ pub enum FfmpegErrorKind {
     /// Failed to obtain video information.
     #[error("Failed to get video properties")]
     Info(#[from] VideoInfoError),
+
+    /// Other
+    #[error("Ffmpeg/ffprobe error: {0}")]
+    Other(String),
 }
